@@ -56,14 +56,6 @@ public:
   CDasherInterfaceBase();
   virtual ~ CDasherInterfaceBase();
 
-  ///
-  /// Allocate resources, create alphabets etc. This is a separate
-  /// routine to the constructor to give us a chance to set up
-  /// parameters before things are created.
-  ///
-
-  void Realize();
-
   /// @name Access to internal member classes
   /// Access various classes contained within the interface. These
   /// should be considered dangerous and use minimised. Eventually to
@@ -162,18 +154,6 @@ public:
 
   void ResetParameter(int iParmater);
   
-  ///
-  /// \todo Document this
-  ///
-
-  void GetAlphabets(std::vector < std::string > *AlphabetList);
-
-  ///
-  /// \todo Document this
-  ///
-
-  void GetColours(std::vector < std::string > *ColourList);
-
   /// \todo Document this
 
   void GetFontSizes(std::vector < int >*FontSizes) const;
@@ -263,15 +243,6 @@ public:
 
   int TrainFile(std::string Filename, int iTotalBytes, int iOffset); // all training data must be in UTF-8.
 
-  /// Get the current autocalibration offset
-  /// \retval The offset.
-
-/*   int GetAutoOffset(); */
-
-  /// Provide a new CDasherInput input device object.
-
-  void CreateInput();
-
   /// Set the context in which Dasher makes predictions
   /// \param strNewContext The new context (UTF-8)
 
@@ -327,9 +298,6 @@ public:
   void AddActionButton(const std::string &strName);
 
   /// @}
-  
-  virtual void WriteTrainFile(const std::string &strNewText) {
-  };
 
   /// @name User input
   /// Deals with forwarding user input to the core
@@ -348,8 +316,6 @@ public:
   // Module management functions
   void RegisterFactory(CModuleFactory *pFactory);
 
-  void CreateFactories();
-
   void StartShutdown();
 
   void AddGameModeString(const std::string &strText) {
@@ -366,10 +332,210 @@ public:
   void CheckRedraw();
    
 protected:
+
+  /// @name Startup
+  /// Interaction with the derived class during core startup
+  /// @{
+
+  ///
+  /// Allocate resources, create alphabets etc. This is a separate
+  /// routine to the constructor to give us a chance to set up
+  /// parameters before things are created.
+  ///
+
+  void Realize();
+
+  ///
+  /// Notify the core that the UI has been realised. At this point drawing etc. is expected to work
+  ///
+
+  void OnUIRealised();
+
+  /// @}
+
+  enum ETransition {
+    TR_MODEL_INIT = 0,
+    TR_UI_INIT,
+    TR_LOCK,
+    TR_UNLOCK,
+    TR_SHUTDOWN,
+    TR_NUM
+  };
+
+  enum EState {
+    ST_START = 0,
+    ST_MODEL,
+    ST_UI,
+    ST_NORMAL,
+    ST_LOCKED,
+    ST_SHUTDOWN,
+    ST_NUM,
+    ST_FORBIDDEN,
+    ST_DELAY
+  };
+
+  /// @name State machine functions
+  /// ...
+  /// @{
+
+  void ChangeState(ETransition iTransition);
+
+  /// @}
+
+  CDasherModule *GetModule(long long int iID);
+  CDasherModule *GetModuleByName(const std::string &strName);
+
+  CEventHandler *m_pEventHandler;
+  CSettingsStore *m_pSettingsStore;
+
+ private:
+  ///
+  /// \todo Document this
+  ///
+
+  void GetAlphabets(std::vector < std::string > *AlphabetList);
+
+  ///
+  /// \todo Document this
+  ///
+
+  void GetColours(std::vector < std::string > *ColourList);
+
+  /// @name Platform dependent utility functions 
+  /// These functions provide various platform dependent functions
+  /// required by the core. A derived class is created for each
+  /// supported platform which implements these.
+  // @{
+  
+  /// 
+  /// Initialise the SP_SYSTEM_LOC and SP_USER_LOC paths - the exact
+  /// method of doing this will be OS dependent
+  ///
+
+  virtual void SetupPaths() = 0;
+
+  /// 
+  /// Produce a list of filenames for alphabet files
+  ///
+
+  virtual void ScanAlphabetFiles(std::vector<std::string> &vFileList) = 0;
+
+  ///
+  /// Produce a list of filenames for colour files
+  ///
+  
+  virtual void ScanColourFiles(std::vector<std::string> &vFileList) = 0;
+
+  ///
+  /// Set up the platform dependent UI for the widget (not the wider
+  /// app). Note that the constructor of the derived class will
+  /// probably want to return details of what was created - this will
+  /// have to happen separately, but we'll need to be careful with the
+  /// semantics.
+  ///
+
+  virtual void SetupUI() = 0;
+
+  ///
+  /// Create any module factories which are specific to the platform
+  /// (eg input device drivers)
+  ///
+
+  virtual void CreateLocalFactories() = 0;
+
+  ///
+  /// Create settings store object, which will be platform dependent
+  /// TODO: Can this not be done just by selecting which settings
+  /// store implementation to instantiate?
+  ///
+
+  virtual void CreateSettingsStore() = 0;
+
+  ///
+  /// Obtain the size in bytes of a file - the way to do this is
+  /// dependent on the OS (TODO: Check this - any posix on Windows?)
+  ///
+
+  virtual int GetFileSize(const std::string &strFileName) = 0;
+
+  ///
+  /// Start the callback timer
+  ///
+
+  virtual void StartTimer() = 0;
+  
+  ///
+  /// Shutdown the callback timer (permenantly - this is called once
+  /// Dasher is committed to closing).
+  ///
+
+  virtual void ShutdownTimer() = 0;
+
+  ///
+  /// Append text to the trainign file - used to store state between
+  /// sessions
+  /// @todo Pass file path to the fuction rather than having implementations work it out themselves
+  ///
+  
+  virtual void WriteTrainFile(const std::string &strNewText) {
+  };
+
+  /// @}
+
+
+  /// Provide a new CDasherInput input device object.
+
+  void CreateInput();
+
+  void CreateFactories();
+  void CreateInputFilter();
+  void CreateDasherModel();
+  void ChangeAlphabet();
+  void ChangeColours();
+  void ChangeView();
+  void Redraw(bool bRedrawNodes);
+  void SetupActionButtons();
+  void DestroyActionButtons();
+  void PositionActionButtons();
+  bool DrawActionButtons();
+
+  void LeaveState(EState iState);
+  void EnterState(EState iState);
+
   void WriteTrainFileFull();
   void WriteTrainFilePartial();
 
-  // Various 'child' components
+  
+  /// @name Lock Management
+  /// Functions for locking/unlocking the core. Note that the lock
+  /// flags parameter is currently ignored, but will be used to give
+  /// finer granularity
+  /// @{
+
+  ///
+  /// Add a lock
+  ///
+
+  void AddLock(int iLockFlags);
+
+  ///
+  /// Release an existing lock. Note that these functions have minimal
+  /// error checking at the moment, so be careful.
+  ///
+
+  void ReleaseLock(int iLockFlags);
+
+  /// @}
+  
+  std::deque<std::string> m_deGameModeStrings;
+
+  std::vector<CActionButton *> m_vLeftButtons;
+  std::vector<CActionButton *> m_vRightButtons;
+
+
+  /// @name Child components
+  /// Various objects which are 'owned' by the core. 
+  /// @{
   CAlphabet *m_Alphabet;
   CDasherModel *m_pDasherModel;
   CDasherScreen *m_DasherScreen;
@@ -378,54 +544,23 @@ protected:
   CAlphIO *m_AlphIO;
   CColourIO *m_ColourIO;
   CNodeCreationManager *m_pNCManager;
+  CUserLogBase *m_pUserLog; 
+  CInputFilter* m_pInputFilter;
+  CModuleManager m_oModuleManager;
+  /// @}
 
   std::string strTrainfileBuffer;
   std::string strCurrentContext;
 
-  CEventHandler *m_pEventHandler;
-  CSettingsStore *m_pSettingsStore;
-  CUserLogBase *m_pUserLog;               // Pointer to the object that handles logging user activity
-  CInputFilter* m_pInputFilter;
-  CModuleManager m_oModuleManager;
-  
+  /// @name State variables
+  /// Represent the current overall state of the core
+  /// @{
   bool m_bGlobalLock; // The big lock
-  bool m_bShutdownLock;
-  bool m_bRecreateLock;
-  
-  // TODO: Make private?
-  CDasherModule *GetModule(long long int iID);
-  CDasherModule *GetModuleByName(const std::string &strName);
-
   bool m_bRedrawScheduled;
-
- private:
-  // To be implemented by child class (TODO - should these be private?)
-  virtual void ScanAlphabetFiles(std::vector<std::string> &vFileList) = 0;
-  virtual void ScanColourFiles(std::vector<std::string> &vFileList) = 0;
-  virtual void SetupPaths() = 0;
-  virtual void SetupUI() = 0;
-  virtual void CreateSettingsStore() = 0;
-  virtual int GetFileSize(const std::string &strFileName) = 0;
-
-  void CreateInputFilter();
-  void CreateDasherModel();
-  void ChangeAlphabet();
-  void ChangeColours();
-  void ChangeView();
-
-  void Redraw(bool bRedrawNodes);                // correct speed.
-
-  void SetupActionButtons();
-  void DestroyActionButtons();
-  void PositionActionButtons();
-  bool DrawActionButtons();
-
-  std::deque<std::string> m_deGameModeStrings;
-
-  std::vector<CActionButton *> m_vLeftButtons;
-  std::vector<CActionButton *> m_vRightButtons;
-
+  int m_iLockCount;
+  EState m_iCurrentState;
   bool m_bOldVisible;
+  /// @}
 };
 
 #endif /* #ifndef __DasherInterfaceBase_h__ */
