@@ -13,7 +13,10 @@
 #include "Alphabet/GroupInfo.h"
 
 #include <deque>
-//#include <iostream>
+#include <iostream>
+
+// Node flag constants
+#define NF_COMMITTED 1
 
 // CDasherNode represents a rectangle and character 
 
@@ -52,11 +55,10 @@ class Dasher::CDasherNode:private NoClones {
   void Delete_children();
   void Trace() const;           // diagnostic
   CDasherNode *const Get_node_under(int, myint y1, myint y2, myint smousex, myint smousey);   // find node under given co-ords
-  void Get_string_under(const int, const myint y1, const myint y2, const myint smousex, const myint smousey, std::vector<symbol> &) const;   // get string under given co-ords
 
   // Lower and higher bounds, and the range
-  int Lbnd() const;
-  int Hbnd() const;
+  inline int Lbnd() const;
+  inline int Hbnd() const;
 
   void SetRange(int iLower, int iUpper) {
     m_iLbnd = iLower;
@@ -87,29 +89,26 @@ class Dasher::CDasherNode:private NoClones {
     m_bSeen = seen;
   }
 
-  symbol Symbol() const { 
-    return m_Symbol; 
-  }
-
-  int Phase() const {
-    return m_iPhase;
-  }
-  // DJW Sort out the colour scheme / phase confusion 
-  Opts::ColorSchemes ColorScheme() const {
-    return m_ColorScheme;
-  } 
   int Colour() const {
     return m_iColour;
   } 
 
+  void SetColour(int iColour) {
+    m_iColour = iColour;
+  }
 
-  // Set/replace the context
-  void SetContext(CLanguageModel::Context Context);
-  CLanguageModel::Context Context()const;
+  void SetGame(bool bInGame) {
+    m_bInGame = bInGame;
+  }
+
+  bool GetGame() {
+    return m_bInGame;
+  }
 
   bool HasAllChildren() const {
     return m_bHasAllChildren;
   };
+
   void SetHasAllChildren(bool val) {
     m_bHasAllChildren = val;
   };
@@ -117,6 +116,17 @@ class Dasher::CDasherNode:private NoClones {
   // Get the probability of this node
   double GetProb(int iNormalization);
 
+  bool GetConverted() {
+    return m_bConverted;
+  };
+
+  /// Ensure that this node is marked as being converted, together with
+  /// all of its ancestors (assuming that unconverted nodes are
+  /// 'contiguous' at the brances of the tree).
+  /// TODO: replace with a generic 'recursive set flag'?
+  
+  void ConvertWithAncestors();
+
   // New stuff
   CNodeManager *m_pNodeManager;
 
@@ -159,11 +169,44 @@ class Dasher::CDasherNode:private NoClones {
 
   SGroupInfo *m_pBaseGroup;
 
- private:
+  // Members only useful for debugging purposes
+  bool m_bWatchDelete; // Notify when this node is deleted
 
-  // Information required to display the node
-  Opts::ColorSchemes m_ColorScheme;
-  int m_iPhase;                 // index for coloring
+  /// 
+  /// Set various flags corresponding to the state of the node. The following flags are defined:
+  ///
+  /// NF_COMMITTED - Node is 'above' the root, so corresponding symbol
+  /// has been added to text box, language model trained etc
+  ///
+  /// NF_ACTIVE - Not yet implemented
+  ///
+  /// NF_ALIVE - Not yet implemented
+  ///
+  /// NF_SEEN - Not yet implemented
+  ///
+  /// NF_CONVERTED - Not yet implemented
+  ///
+  /// NF_GAME - Not yet implemented
+  ///
+
+  void SetFlag(int iFlag, bool bValue) {
+    if(bValue)
+      m_iFlags = m_iFlags | iFlag;
+    else
+      m_iFlags = m_iFlags & (~iFlag);
+
+    m_pNodeManager->SetFlag(this, iFlag, bValue);
+  }
+
+  ///
+  /// Get the value of a flag for this node
+  ///
+
+  bool GetFlag(int iFlag) {
+    return (m_iFlags & iFlag);
+  }
+
+ private:
   int m_iColour;                // for the advanced colour mode
   int m_iLbnd;
   int m_iHbnd;   // the cumulative lower and upper bound prob relative to parent
@@ -173,16 +216,20 @@ class Dasher::CDasherNode:private NoClones {
   int m_iRefCount;              // reference count if ancestor of (or equal to) root node
   bool m_bAlive;                // if true, then display node, else dont bother
   bool m_bSeen;                 // if true, node has been output already
+
+  // Whether this node has been converted (and can therefore be safely deleted)
+  bool m_bConverted;            
+
+  // Whether this is on the game mode path
+  bool m_bInGame;
   
   // Information internal to the data structure
   ChildMap m_mChildren;         // pointer to array of children
   bool m_bHasAllChildren;       // true if we haven't deleted any children after instantiating them
   CDasherNode *m_pParent;       // pointer to parent
 
-  // TODO: The following should be included in m_pUserData, as they only apply to nodes managed by CAlphabetManager
-  CLanguageModel *m_pLanguageModel;     // pointer to the language model - in future, could be different for each node      
-  CLanguageModel::Context m_Context;
-  const symbol m_Symbol;        // the character to display
+  // Binary flags representing the state of the node
+  int m_iFlags;
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -194,25 +241,21 @@ using namespace Opts;
 #include "DasherModel.h"
 
 inline CDasherNode::CDasherNode(CDasherNode *pParent, symbol Symbol, int iphase, ColorSchemes ColorScheme, int ilbnd, int ihbnd, CLanguageModel *lm, int Colour =-1)
-:m_iLbnd(ilbnd), m_iHbnd(ihbnd), m_Symbol(Symbol), m_mChildren(), m_bHasAllChildren(false), m_bIsActive(true), m_iRefCount(0), m_bAlive(true), m_bSeen(false), m_ColorScheme(ColorScheme), m_iPhase(iphase), m_iColour(Colour), m_pLanguageModel(lm), m_Context(CLanguageModel::nullContext), m_pParent(pParent) {
-}
+  : m_mChildren() {
 
-inline CDasherNode::~CDasherNode() {
+  m_iLbnd = ilbnd;
+  m_iHbnd = ihbnd;
+  m_bIsActive = true;
+  m_bHasAllChildren = false;
+  m_iRefCount = 0;
+  m_bAlive = true;
+  m_iColour = Colour;
+  m_bSeen = false;
+  m_pParent = pParent;
 
-  // Release any storage that the node manager has allocated,
-  // unreference ref counted stuff etc.
-
-  m_pNodeManager->ClearNode( this );
-
-  Delete_children();
-  if(m_Context)
-    m_pLanguageModel->ReleaseContext(m_Context);
-}
-
-inline void CDasherNode::SetContext(CLanguageModel::Context Context) {
-  if(m_Context)
-    m_pLanguageModel->ReleaseContext(m_Context);
-  m_Context = Context;
+  m_bConverted = false;
+  m_bInGame = false;
+  m_bWatchDelete = false;
 }
 
 inline int CDasherNode::Lbnd() const {
@@ -238,8 +281,4 @@ inline const CDasherNode::ChildMap &CDasherNode::GetChildren() const {
   return m_mChildren;
 }
 
-inline CLanguageModel::Context CDasherNode::Context() const {
-  return m_Context;
-}
-
 #endif /* #ifndef __DasherNode_h__ */
