@@ -13,8 +13,8 @@ class CDynamicFilter : public CTwoButtonDynamicFilter {
   virtual bool GetSettings(SModuleSettings **pSettings, int *iCount);
 
  protected:
-  virtual bool TimerImpl(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel);
-  virtual void ActionButton(int iTime, int iButton, CDasherModel *pModel);
+  virtual bool TimerImpl(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel, Dasher::VECTOR_SYMBOL_PROB *pAdded, int *pNumDeleted);
+  virtual void ActionButton(int iTime, int iButton, int iType, CDasherModel *pModel, CUserLogBase *pUserLog);
   
  private:
   int m_iTarget;
