@@ -7,10 +7,11 @@ class COneDimensionalFilter : public CDefaultFilter {
  public:
   COneDimensionalFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, CDasherModel *m_pDasherModel);
 
-  bool GetSettings(SModuleSettings **pSettings, int *iCount);
-
  private:
    virtual void ApplyTransform(myint &iDasherX, myint &iDasherY);
+
+   int iLastY;
+   int iOffset;
 };
 
 #endif
