@@ -45,7 +45,7 @@ static UserLogParamMask s_UserLogParamMaskTable [] = {
 CUserLog::CUserLog(Dasher::CEventHandler *pEventHandler, 
                    CSettingsStore *pSettingsStore, 
                    int iLogTypeMask, 
-                   Dasher::CAlphabet* pAlphabet) : CDasherComponent(pEventHandler, pSettingsStore)
+                   Dasher::CAlphabet* pAlphabet) : CUserLogBase(pEventHandler, pSettingsStore)
 {
   //CFunctionLogger f1("CUserLog::CUserLog", g_pLogger);
 
@@ -254,7 +254,7 @@ void CUserLog::StopWriting()
         return;
       }
 
-      pTrial->StopWriting();
+      pTrial->StopWriting(GetCycleBits());
     }
   }
 }
@@ -696,6 +696,13 @@ int CUserLog::GetLogLevelMask()
 
   return m_iLevelMask;
 }
+
+void CUserLog::KeyDown(int iId, int iType, int iEffect) {
+  CUserLogTrial* pTrial = GetCurrentTrial();
+  
+  if(pTrial)
+    pTrial->AddKeyDown(iId, iType, iEffect);
+}
   
 // This gets called whenever parameters get changed that we are tracking
 void CUserLog::HandleEvent(Dasher::CEvent* pEvent)
@@ -813,7 +820,7 @@ string CUserLog::GetXML()
   {
     CUserLogTrial* pTrial = (CUserLogTrial*) m_vpTrials[i];
 
-    // Only log trials that actually had some writing in it
+   // Only log trials that actually had some writing in it
     if ((pTrial != NULL) && (pTrial->HasWritingOccured()))
     {
       strResult += pTrial->GetXML("\t\t");
@@ -1021,8 +1028,8 @@ void CUserLog::PrepareNewTrial()
     VECTOR_STRING vFound;
     if (m_vParams.size() > 0)
     {
-      for (VECTOR_USER_LOG_PARAM_PTR_ITER iter = m_vParams.end() - 1; iter >= m_vParams.begin(); iter--)
-      {
+	  for (VECTOR_USER_LOG_PARAM_PTR_REV_ITER iter = m_vParams.rbegin(); iter != m_vParams.rend(); ++iter)
+	  {
         if (((*iter) != NULL) && ((*iter)->options & userLogParamForceInTrial))
         {
           // Make sure we haven't output this one already
@@ -1169,7 +1176,7 @@ void CUserLog::UpdateParam(int iParameter, int iOptionMask)
 // UserLog XML files and does cool things to them.  
 
 // Load the object from an XML file
-CUserLog::CUserLog(string strXMLFilename) : CDasherComponent(NULL, NULL)
+CUserLog::CUserLog(string strXMLFilename) : CUserLogBase(NULL, NULL)
 {
   //CFunctionLogger f1("CUserLog::CUserLog(XML)", g_pLogger);
 
