@@ -31,12 +31,12 @@ extern "C" void open_file(const char *myfilename) {
   if(size != 0) {
     // Don't attempt to insert new text if the file is empty as it makes
     // GTK cry
-    if(g_utf8_validate(buffer, size, NULL) == FALSE) {
+    if(!g_utf8_validate(buffer, size, NULL)) {
       // It's not UTF8, so we do the best we can...
 
       // If there are zero bytes in the file then we have a problem -
       // for now, just assert that we can't load these files.
-      for(int i(0); i < size; ++i)
+      for(unsigned int i(0); i < size; ++i)
 	if(buffer[i] == 0) {
 	  GtkWidget *pErrorBox = gtk_message_dialog_new(GTK_WINDOW(window), 
 							GTK_DIALOG_MODAL, 
@@ -54,9 +54,10 @@ extern "C" void open_file(const char *myfilename) {
       gsize iNewSize;
       gchar *buffer2 = g_strdup(g_locale_to_utf8(buffer, size, NULL, &iNewSize, NULL));
 
-      const gchar *pEnd;
+      // TODO: This function probably needs more thought
 
-      gboolean bValid = g_utf8_validate(buffer2, -1, &pEnd);
+      //      const gchar *pEnd;
+      //gboolean bValid = g_utf8_validate(buffer2, -1, &pEnd);
 
       g_free(buffer);
       buffer = buffer2;
@@ -157,10 +158,11 @@ gboolean unix_vfs_open_file(const char *myfilename, gchar **buffer, unsigned lon
 extern "C" bool save_file_as(const char *myfilename, bool append) {
   unsigned long long length;
   gchar *inbuffer, *outbuffer = NULL;
-  gsize bytes_read, bytes_written;
-  GError *error = NULL;
+  //  gsize bytes_read, bytes_written;
+  gsize bytes_written;
+  //  GError *error = NULL;
   GtkTextIter *start, *end;
-  GIConv cd;
+  //  GIConv cd;
 
   start = new GtkTextIter;
   end = new GtkTextIter;
@@ -170,8 +172,16 @@ extern "C" bool save_file_as(const char *myfilename, bool append) {
 
   inbuffer = gtk_text_iter_get_slice(start, end);
 
+  //  g_message("String %s", inbuffer);
+
+  //length = gtk_text_iter_get_offset(end) - gtk_text_iter_get_offset(start);
+  //length = gtk_text_buffer_get_byte_count(GTK_TEXT_BUFFER(the_text_buffer));
+
+  // I'm pretty certain that this is null terminated, but not 100%
   length = strlen(inbuffer);
 
+  //  g_message("Length is %d", length);
+
   outbuffer = (char *)malloc((length + 1) * sizeof(gchar));
   memcpy((void *)outbuffer, (void *)inbuffer, length * sizeof(gchar));
   outbuffer[length] = 0;
