@@ -116,7 +116,7 @@ GtkWidget *module_settings_window_new(DasherAppSettings *pAppSettings, const gch
   
  
   for(int i(0); i < iCount; ++i) {
-    GtkWidget *pControl;
+    GtkWidget *pControl = NULL;
     
     if(pSettings[i].iType == T_BOOL) {
       pControl = gtk_check_button_new_with_label(pSettings[i].szDescription); 
@@ -139,6 +139,9 @@ GtkWidget *module_settings_window_new(DasherAppSettings *pAppSettings, const gch
 					     pSettings[i].iMax / static_cast<double>(pSettings[i].iDivisor), 
 					     pSettings[i].iStep / static_cast<double>(pSettings[i].iDivisor));
 	
+	gtk_range_set_increments(GTK_RANGE(pControl), pSettings[i].iStep / static_cast<double>(pSettings[i].iDivisor),
+				 pSettings[i].iStep / static_cast<double>(pSettings[i].iDivisor));
+
 	gtk_range_set_value(GTK_RANGE(pControl), 
 			    dasher_app_settings_get_long(pPrivate->pAppSettings, pSettings[i].iParameter) 
 			    / static_cast<double>(pSettings[i].iDivisor));
@@ -230,7 +233,7 @@ void module_settings_window_handle_long_changed(ModuleSettingsWindow *pSelf, Gtk
 
   ModuleSettingsWindowPrivate *pPrivate((ModuleSettingsWindowPrivate *)(pSelf->private_data));
 
-  gint iNewValue = gtk_range_get_value(pRange) * pData->iDivisor;
+  gint iNewValue = (gint)(gtk_range_get_value(pRange) * pData->iDivisor);
   dasher_app_settings_set_long(pPrivate->pAppSettings, pData->iParameter, iNewValue);
 }
 
@@ -242,7 +245,7 @@ void module_settings_window_handle_longspin_changed(ModuleSettingsWindow *pSelf,
 
   ModuleSettingsWindowPrivate *pPrivate((ModuleSettingsWindowPrivate *)(pSelf->private_data));
 
-  gint iNewValue = gtk_spin_button_get_value(pSpinButton) * pData->iDivisor;
+  gint iNewValue = (gint)(gtk_spin_button_get_value(pSpinButton) * pData->iDivisor);
   dasher_app_settings_set_long(pPrivate->pAppSettings, pData->iParameter, iNewValue);
 }
 
